@@ -6,8 +6,9 @@ import os
 import shutil
 from contextlib import contextmanager
 from natsort import natsorted
-from config import CONFIG
+from msg2po.config import CONFIG
 from datetime import datetime
+from msg2po.common import find_files, get_ext
 
 # extensions recognized by file2po, etc
 VALID_EXTENSIONS = ["msg", "txt", "sve", "tra"]
@@ -78,12 +79,6 @@ CONTEXT_FEMALE = "female"
 
 # file and dir manipulation
 #################################
-def get_ext(path):
-    try:
-        ext = path.rsplit(".", 1)[1].lower()
-    except:
-        ext = None
-    return ext
 
 
 def basename(path):
@@ -147,18 +142,6 @@ def dir_or_exit(d):
         sys.exit(1)
 
 
-def find_files(dir: str, ext: str):
-    """
-    Find files with extension ext in directory dir
-    """
-    files = []
-    for root, subdir_list, file_list in os.walk(dir):
-        for f in file_list:
-            if get_ext(f) == ext:
-                files.append((os.path.join(root, f)))
-    return files
-
-
 @contextmanager
 def cd(newdir):
     prevdir = os.getcwd()
@@ -178,6 +161,7 @@ def get_enc(lang_path: str = "", file_path: str = ""):
         "schinese": "cp936",
         "tchinese": "cp950",
         "czech": "cp1250",
+        "hungarian": "cp1250",
         "japanese": "cp932",
         "korean": "cp949",
         "polish": "cp1250",
@@ -214,7 +198,7 @@ def get_enc(lang_path: str = "", file_path: str = ""):
     ]
 
     encoding = CONFIG.encoding
-    lang = strip_ext(basename(lang_path))
+    lang = language_slug(lang_path)
     filename = basename(file_path)
 
     if lang in ENCODINGS:
@@ -444,7 +428,7 @@ def po2file(
             lines_female.append(female_line.encode(encoding, "replace").decode(encoding))
 
     # write main package
-    with open(output_file, "w", encoding=encoding, newline=CONFIG.newline) as file:
+    with open(output_file, "w", encoding=encoding, newline=CONFIG.newline_tra) as file:
         file.writelines(lines)
 
     # explicitly disabled female?
@@ -455,22 +439,31 @@ def po2file(
         same = False
         if lines_female == lines:
             same = True
+
         # what's out path?
         female_file = get_female_filepath(output_file, dst_dir, same)
 
-        if female_file is False:  # don't need to copy, automatic fallback
-            print("  Female strings are same, not copying - sfall will fallback to male {}".format(output_file))
-            return True  # cutoff the rest of the function
-
         # If need to create the file
         if same:  # if female translation is the same?
-            print("  Female strings are same, copying to {}".format(female_file))
-            copycreate(output_file, female_file)
+            if female_file is False:  # don't need to copy, automatic fallback
+                print("  Female strings are same, not copying - sfall will fallback to male {}".format(output_file))
+                return True  # cutoff the rest of the function
+            else:
+                print("  Female strings are same, copying to {}".format(female_file))
+                copycreate(output_file, female_file)
         else:  # if it's different, extract separately
-            print("  Also extracting female counterpart into {}".format(female_file))
-            create_dir(get_dir(female_file))  # create dir if not exists
-            with open(female_file, "w", encoding=encoding, newline=CONFIG.newline) as file2:
-                file2.writelines(lines_female)
+            if female_file is False:
+                print(
+                    "  WARN: female strings are different, but female file is not supported for path {}".format(
+                        output_file
+                    )
+                )
+                return True
+            else:
+                print("  Also extracting female counterpart into {}".format(female_file))
+                create_dir(get_dir(female_file))  # create dir if not exists
+                with open(female_file, "w", encoding=encoding, newline=CONFIG.newline_tra) as file2:
+                    file2.writelines(lines_female)
 
 
 # nasty hack for sfall's female strings placement
@@ -513,7 +506,12 @@ def copycreate(src_file, dst_file):
 
 
 def file2msgstr(
-    input_file: str, po: polib.POFile, path: str, encoding=CONFIG.encoding, overwrite: bool = True, same: bool = False
+    input_file: str,
+    po: polib.POFile,
+    occurence_path: str,
+    encoding=CONFIG.encoding,
+    overwrite: bool = True,
+    same: bool = False,
 ):
     """returns PO file object"""
 
@@ -533,12 +531,12 @@ def file2msgstr(
         female_value = t.female
 
         if (value is None) or (value == ""):
-            print("WARN: no msgid found for {}:{}, skipping string\n      {}".format(path, index, value))
+            print("WARN: no msgid found for {}:{}, skipping string\n      {}".format(occurence_path, index, value))
             continue
 
-        if (path, index) in entries_dict:
+        if (occurence_path, index) in entries_dict:
             # map entries to occurrences for faster access, part 2
-            e = entries_dict[(path, index)]
+            e: polib.POEntry = entries_dict[(occurence_path, index)]
 
             # female entries have no occurences
             if female_value and e.msgid in female_map:
@@ -571,6 +569,7 @@ def file2msgstr(
                         if "fuzzy" in fe.flags:
                             print("    Unfuzzied female entry")
                             fe.flags.remove("fuzzy")
+                            fe.previous_msgid = None
 
             # translation is the same
             if e.msgstr == value and e.msgctxt == context:
@@ -602,6 +601,7 @@ def file2msgstr(
             if "fuzzy" in e.flags:
                 print("    Unfuzzied entry")
                 e.flags.remove("fuzzy")
+                e.previous_msgid = None
 
     return po
 
@@ -820,7 +820,7 @@ class TRANSFile:
         return lines
 
 
-def simple_lang_slug(po_filename):
+def language_slug(po_filename):
     """
     Allows to extract PO files into simplified language names: pt_BR.po -> portuguese/1.msg.
     Working with language codes is not convenient in mods.
@@ -836,7 +836,7 @@ def simple_lang_slug(po_filename):
         "ru": "russian",
         "uk": "ukrainian",
     }
-    slug = strip_ext(po_filename).lower()
+    slug = strip_ext(basename(po_filename)).lower()
     if CONFIG.simple_languages:
         try:
             slug = slug_map[slug]
@@ -873,3 +873,39 @@ def restore_female_entries(po: polib.POFile):
                 e.flags.append("fuzzy")
             e.obsolete = False
     return po
+
+
+def unfuzzy_exact_matches(po: polib.POFile):
+    """
+    For some reason msgmerge won't clear fuzzy flag if source string is changed, then changed back:
+    #: game/g_map_hotkey.msg:1
+    #, fuzzy
+    #| msgid "Nah... I think I'm gonna take the ladder."
+    msgid "Nah... I think I'm gonna take the ladder."
+    msgstr "Naa... Penso che prendero' la scala."
+
+    This function unfuzzies such entries.
+    """
+    for e in po.fuzzy_entries():
+        if e.previous_msgid == e.msgid:
+            print("    Unfuzzied entry {}, msgid is the same as previous_msgid".format(e.occurrences))
+            e.flags.remove("fuzzy")
+            e.previous_msgid = None
+    return po
+
+
+class LanguageMap:
+    """
+    map PO basenames to language dir names, for unpoify and dir2msgstr
+    This is because languages added through Weblate use codes like pt_BR, see find_files
+    """
+
+    def __init__(self):
+        po_files = find_files(CONFIG.po_dir, "po")
+        self.slug2po = {}
+        self.po2slug = {}
+        for pf in po_files:
+            pf = basename(pf)
+            slug = language_slug(pf)
+            self.slug2po[slug] = pf
+            self.po2slug[pf] = slug
